@@ -31,7 +31,9 @@ describe 'manila::api' do
       is_expected.to contain_manila_config('DEFAULT/auth_strategy').with(:value => 'keystone')
       is_expected.to contain_manila_config('DEFAULT/osapi_share_listen').with(:value => '0.0.0.0')
       is_expected.to contain_manila_config('DEFAULT/enabled_share_protocols').with(:value => '<SERVICE DEFAULT>')
-      is_expected.to contain_manila_config('oslo_middleware/enable_proxy_headers_parsing').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_oslo__middleware('manila_config').with(
+        :enable_proxy_headers_parsing => '<SERVICE DEFAULT>',
+      )
       is_expected.to contain_manila_config('DEFAULT/default_share_type').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_manila_config('DEFAULT/osapi_share_workers').with(:value => '2')
     end
@@ -83,8 +85,8 @@ describe 'manila::api' do
     end
     it { is_expected.to contain_class('manila::policy') }
     it 'should configure manila api correctly' do
-      is_expected.to contain_manila_config('oslo_middleware/enable_proxy_headers_parsing').with(
-       :value => true
+      is_expected.to contain_oslo__middleware('manila_config').with(
+        :enable_proxy_headers_parsing => true,
       )
     end
   end
