@@ -15,6 +15,7 @@ describe 'manila::db' do
         :max_retries    => '<SERVICE DEFAULT>',
         :retry_interval => '<SERVICE DEFAULT>',
         :max_overflow   => '<SERVICE DEFAULT>',
+        :pool_timeout   => '<SERVICE DEFAULT>',
       )}
 
     end
@@ -27,6 +28,7 @@ describe 'manila::db' do
           :database_max_pool_size  => '21',
           :database_max_retries    => '11',
           :database_max_overflow   => '21',
+          :database_pool_timeout   => '21',
           :database_retry_interval => '11',
           :database_db_max_retries => '-1', }
       end
@@ -40,6 +42,7 @@ describe 'manila::db' do
         :max_retries    => '11',
         :retry_interval => '11',
         :max_overflow   => '21',
+        :pool_timeout   => '21',
       )}
 
     end
